#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-meta
version:              2.7.8
visibility:           public
id:                   hspec-meta-2.7.8-BRd0xpWN6w51opERRt6i6J
key:                  hspec-meta-2.7.8-BRd0xpWN6w51opERRt6i6J
license:              MIT
copyright:
    (c) 2011-2021 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.

category:             Testing
abi:                  bc873efb709d08edb13a35bea6af38ae
exposed:              True
exposed-modules:      Test.Hspec.Meta
hidden-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Options Test.Hspec.Core.Config.Util
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Format
    Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner Test.Hspec.Core.Runner.Eval
    Test.Hspec.Core.Shuffle Test.Hspec.Core.Spec
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Test.Hspec.Core.Util Control.Concurrent.Async
    Data.Algorithm.Diff Test.HUnit Test.HUnit.Base Test.HUnit.Lang
    Test.HUnit.Terminal Test.HUnit.Text Test.Hspec.Expectations
    Test.Hspec.Expectations.Contrib Test.Hspec.Expectations.Matcher
    Paths_hspec_meta

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-meta-2.7.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-meta-2.7.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-meta-2.7.8
hs-libraries:         HShspec-meta-2.7.8-BRd0xpWN6w51opERRt6i6J
depends:
    QuickCheck-2.14.2-LYkEXWaccd95SoKseYSYTk
    ansi-terminal-0.11-366lZebL4UKAFopo4Q1x1i array-0.5.4.0
    base-4.14.2.0 call-stack-0.3.0-HaJG5jRa2XM74od97nDj56
    clock-0.8.2-CUh6FGzlB8CArRlXh1LKmY deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    quickcheck-io-0.2.0-2k9LyfDsBgAKpyNTLuqexm
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub
    setenv-0.1.1.3-ADyKsIah1zg4WlxP7oqCU1 stm-2.5.0.1 time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html:         /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

